@@ -1461,6 +1461,7 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, verbose=
             seglow = ants.resample_image( seghigh, tarshape, use_voxels=False, interp_type=1 )
             dimgup=inference( dimg, srmdl, segmentation = seglow, verbose=verbose )
             dimgupseg = dimgup['super_resolution_segmentation']
+            dimgup = dimgup['super_resolution']
             segimgnn = ants.resample_image_to_target( seglow, dimgupseg, interp_type='nearestNeighbor' )
             dicenn = ants.label_overlap_measures(seghigh, segimgnn)['MeanOverlap'][0]
             dicesr = ants.label_overlap_measures(seghigh, dimgupseg)['MeanOverlap'][0]
@@ -1468,8 +1469,8 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, verbose=
             dimgup=inference( dimg, srmdl, verbose=verbose )
         dimglin = ants.resample_image_to_target( dimg, dimgup, interp_type='linear' )
         imgblock = ants.resample_image_to_target( img, dimgup, interp_type='linear'  )
-        dimgup[ imgblock == 0 ]=0
-        dimglin[ imgblock == 0 ]=0
+        dimgup[ imgblock == 0.0 ]=0.0
+        dimglin[ imgblock == 0.0 ]=0.0
         padder = []
         dimwarning=False
         for jj in range(img.dimension):
